@@ -12,8 +12,8 @@ from wlroots import Ptr, PtrHasData, ffi, lib, str_or_none
 from wlroots.util.box import Box
 from wlroots.util.edges import Edges
 
+from .compositor import Surface
 from .output import Output
-from .surface import Surface
 
 _weakkeydict: weakref.WeakKeyDictionary = weakref.WeakKeyDictionary()
 
@@ -87,8 +87,8 @@ class XdgSurface(PtrHasData):
             data_wrapper=XdgSurfaceConfigure,
         )
 
-    @classmethod
-    def from_surface(cls, surface: Surface) -> XdgSurface:
+    @staticmethod
+    def from_surface(surface: Surface) -> XdgSurface:
         """Get the xdg surface associated with the given surface"""
         if not surface.is_xdg_surface:
             raise RuntimeError("Surface is not XDG surface")
